<?php
/**
 *  This file is part of devMX TeamSpeak3 Webviewer for Wordpress.
 *  Copyright (C) 2012  Maximilian Narr
 *
 *  devMX TeamSpeak3 Webviewer for Wordpress is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  TeamSpeak3 Webviewer is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with devMX TeamSpeak3 Webviewer for Wordpress.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace devmx\Wordpress\TSViewer;

class TSViewerWidget extends \WP_Widget
{

    const BASE_NAME = "tswv";
    const WIDGET_NAME = "TeamSpeak3 Webviewer";
    const TABLE_NAME = "tswebviewer";

    protected $wpdb;
    protected $tableName;
    protected $options;

    public function __construct()
    {
        $options = array("configuration" => 0, "title" => __('New title', 'tswv'), "maxHeight" => "");
        $this->options = $options;

        parent::__construct(
                self::BASE_NAME, self::WIDGET_NAME, array('description' => __('A widget which displays the devMX TeamSpeak3 Webviewer in the sidebar', 'tswv'))
        );

        global $wpdb;
        $this->wpdb = $wpdb;
        $this->tableName = $this->wpdb->prefix . self::TABLE_NAME;
    }

    /**
     * Displays the TeamSpeak3 Webviewer
     * @see WP_Widget::widget()
     * @param array $args     Widget arguments.
     * @param array $instance Saved values from database.
     * @author Maximilian Narr
     * @since 1.1
     */
    public function widget($args, $instance)
    {
        extract($args);
        $title = apply_filters('widget_title', $instance['title']);

        $html = "";
        $html .= $before_widget;

        if (!empty($title)) $html .= $before_title . $title . $after_title;

        $viewerId = strip_tags($instance['configuration']);

        // Set max height if appropriate
        if (isset($instance['maxHeight']) && $instance['maxHeight'] !== "")
        {
            $html .= sprintf('<div style="height: %s; overflow-y: scroll; overflow-x: hidden;" class="devmx-webviewer-wrapper">', $instance['maxHeight']);
        }
        else
        {
            $html .= '<div style="overflow-x: hidden;" class="devmx-webviewer-wrapper">';
        }

        // Render TS Webviewer
        $html .= do_shortcode("[tswv id={$viewerId}]");

        $html .= '</div>';

        $html .= $after_widget;

        echo ($html);
    }

    /**
     * Sanitize widget form values as they are saved.
     * @see WP_Widget::update()
     * @param array $newInstance Values just sent to be saved.
     * @param array $oldInstance Previously saved values from database.
     * @return array Updated safe values to be saved.
     * @author Maximilian Narr
     * @since 1.1
     */
    public function update($newInstance, $oldInstance)
    {
        $instance = $oldInstance;

        $instance['title'] = $newInstance['title'];
        $instance['configuration'] = $newInstance['configuration'];
        $instance['maxHeight'] = $newInstance['maxHeight'];

        return $instance;
    }

    /**
     * Displays the widgets option page
     * @see WP_Widget::form()
     * @param array $instance Previously saved values from database.
     * @author Maximilian Narr
     * @since 1.1
     */
    public function form($instance)
    {
        $configurations = $this->getConfigurations();

        // Set standard values
        foreach ($this->options as $key => $value)
        {
            if (!isset($instance[$key])) $instance[$key] = $value;
        }
        ?>
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:', 'tswv'); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $instance['title'] ?>" />
        </p>
        <p>
            <label for="<?php echo($this->get_field_id("configuration")) ?>"><?php _e('Configuration:', 'tswv') ?></label>
            <select class="widefat" id="<?php echo $this->get_field_id("configuration"); ?>" name="<?php echo $this->get_field_name("configuration"); ?>" size="1">
                <?php foreach ($configurations as $config) : ?>
                    <option <?php if ($instance['configuration'] == $config['id']): ?> selected="selected" <?php endif; ?> value="<?php echo $config['id'] ?>"><?php echo $config['id'] ?> - <?php echo $config['configname'] ?></option>
                <?php endforeach; ?>
            </select>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('maxHeight'); ?>"><?php _e('Max. Height', 'tswv'); ?></label>
            <input type="text" id="<?php echo $this->get_field_id('maxHeight'); ?>" name="<?php echo $this->get_field_name('maxHeight') ?>" value="<?php echo isset($instance['maxHeight']) ? $instance['maxHeight'] : "" ?>" />
            <em><?php _e('Height in px, em, %', 'tswv') ?></em>
        </p>
        <?php
    }

    /**
     * Returns an array containing all available webviewer configuratons
     * @see TSViewer.php
     * @return array All available webviewer configurations
     * @author Maximilian Narr
     * @since 1.1
     */
    private function getConfigurations()
    {
        $sql = "SELECT * FROM " . $this->tableName;

        return $this->wpdb->get_results($sql, ARRAY_A);
    }

}
?>
